@@ -406,85 +406,6 @@ class TestBulkInsert:
         assert actual_sql.startswith("INSERT IGNORE INTO")
 
 
-class TestEntityStats:
-    """Tests for get_entity_stats method."""
-
-    @patch("nui_lambda_shared_utils.db_client.get_database_credentials")
-    def test_get_entity_stats(self, mock_get_creds):
-        """Test entity statistics retrieval."""
-        mock_get_creds.return_value = {
-            "host": "db.example.com",
-            "port": 3306,
-            "username": "dbuser",
-            "password": "dbpass",
-            "database": "testdb",
-        }
-
-        client = DatabaseClient()
-
-        # Mock query responses
-        active_tenants_result = [
-            {"id": 1, "name": "Tenant 1", "schema_name": "tenant1", "user_count": 10},
-            {"id": 2, "name": "Tenant 2", "schema_name": "tenant2", "user_count": 5},
-        ]
-        totals_result = [{"total_entities": 50, "active_entities": 30, "total_users": 150}]
-
-        with patch.object(client, "query") as mock_query:
-            mock_query.side_effect = [active_tenants_result, totals_result]
-
-            stats = client.get_entity_stats()
-
-        assert stats["totals"]["total_entities"] == 50
-        assert stats["totals"]["active_entities"] == 30
-        assert stats["totals"]["total_users"] == 150
-        assert len(stats["top_entities"]) == 2
-        assert stats["top_entities"][0]["name"] == "Tenant 1"
-
-
-class TestRecordStats:
-    """Tests for get_record_stats method."""
-
-    @patch("nui_lambda_shared_utils.db_client.get_database_credentials")
-    def test_get_record_stats(self, mock_get_creds):
-        """Test record statistics retrieval."""
-        mock_get_creds.return_value = {
-            "host": "db.example.com",
-            "port": 3306,
-            "username": "dbuser",
-            "password": "dbpass",
-            "database": "testdb",
-        }
-
-        client = DatabaseClient()
-
-        # Mock query response
-        stats_result = [
-            {
-                "total_orders": 100,
-                "unique_buyers": 25,
-                "unique_sellers": 15,
-                "total_value": 50000.00,
-                "avg_value": 500.00,
-                "confirmed_orders": 80,
-                "cancelled_orders": 20,
-            }
-        ]
-
-        with patch.object(client, "query") as mock_query:
-            mock_query.return_value = stats_result
-
-            stats = client.get_record_stats(hours=48)
-
-        assert stats["total_orders"] == 100
-        assert stats["unique_buyers"] == 25
-        assert stats["total_value"] == 50000.00
-        assert stats["confirmed_orders"] == 80
-
-        # Verify query was called with correct hours parameter
-        mock_query.assert_called_once()
-        assert mock_query.call_args[0][1] == (48,)
-
-
 class TestConnectionRecycling:
     """Tests for connection recycling functionality."""
 
